source("NeighborhoodDataWD.R");
source("Net_Import.R");
source("NetCmbn.R");
source("Para_SIS.R");
source("Para_SAIS_2layer.R");
source("Post_Population.R");
source("Post_NodesState.R");
source("GEMF_SIM.R");
source("GEMF_SIM_Prob.R");
source("NetGen_Geo.R");
source("NetGen_ER.R");



#Generating a multilayer metwork
  N=300;
  Net1=NetGen_Geo(N,0.1)
  Net2=NetGen_ER(N,0.03)
  NetSet=list(Net1,Net2);
  Net=NetCmbn(NetSet,N);

  
#setting up the SAIS_2layer epidemic model
  Para=Para_SAIS_2layer(1,0.2,0.1,0,0.1);     
  M<-Para[[1]];
  
  
#input the initial condition  
  P0=matrix(0,M,N);
  P0[1,]=0.25;
  P0[2,]=0.5;
  P0[3,]=0.25;
  
#simulation terminator 
  maxNumevent=100000;Runtime=5;
  
  
  numrun<-25;
  comp=c(1,2,3);


# we can run simulation on just one core
#lst4<-GEMF_SIM_Prob(Para,Net,X0=NA,maxNumevent,Runtime,N,numrun,timstp=0.1,comp,drawfromprobdis=TRUE,P0);
 
  
   
#Runing simulation in parallel on several cores  
# The cluster function makes the list "result" that has the output of GEMF_SIM_Prob, from different cores, as its elements
  library(parallel);
  numcor=4; 
  timstp=0.1;
  cl<-makeCluster(numcor)
  result<-clusterCall(cl, GEMF_SIM_Prob, Para,Net,X0=NA,maxNumevent,Runtime,N,numrun,timstp,comp,drawfromprobdis=TRUE,P0) 
  stopCluster(cl);

  Tp<-result[[1]][[1]];
  compcu<-result[[1]][[2]];
  for (j in 2:numcor){compcu<-compcu+result[[j]][[2]]};
  s=numcor*numrun;
  comppr<-compcu/s;

  
#plotting some data 
#using packages to make an animation to show the probibility that the nodes occupy
#the specified "compartmant" through time
  library(igraph); 
  library(animation);
  source("colorbar.R");
  source("undirNet_to_edglis.R");
  
  #making a layout for the graph based on the first layer of the network
  edl=undirNet_to_edglis(Net1) 
  g=graph.edgelist(edl,directed=FALSE);
  lay=layout.graphopt(g);
  
  
  
  compartmant<-3;#choose one of the compartmant specified in the "comp" vector  
  
  i<-match(compartmant,comp);
  compipr<-comppr[i,,];
  pre<-colSums(compipr)
  plot(Tp,pre);
  
  #assigning  color to the nodes based on the probability of occupying the 
  #specified "compartmant"  
  numcol=100  #choose number of colors 
  col<-colorRampPalette(c("blue","darkgreen","green","white","yellow", "orange", "red"))(numcol);
  maxp=1; # choose maxrange  
  minp=0;#choose minrange  
  prcl<-floor(((compipr-minp)*(numcol-1)/(maxp-minp))+1);
  prcl[prcl<1]<-1
  prcl[prcl>numcol]<-numcol
  
  numofimages<-length(Tp);#chooseing number of time point be included in the animation

    saveGIF({for(i in 1:numofimages){
      V(g)$color=col[prcl[,i]];
      plot(g, layout=lay, vertex.size=3, vertex.label=NA);
      oldpar<-par(no.readonly=TRUE);
      par(plt=c(4.5,4.7,3.8,4.8)/5,new=TRUE);##setting up the position of colorbar
      colorbar(col, minp,maxp,nticks=5);
      par(oldpar);
      }},
      interval=0.3, ani.width = 1500,ani.height = 1000, movie.name = "SAIS-A-prob.gif", 
      img.name = "SIS",convert = "convert",cmd.fun = system);# choose animation parameters


